==> speech-analytic-testing_2.0.3_database.tar.gz: database/mssql/procedures/GetProcessI6InteractionsToUpdate.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
 CREATE PROCEDURE [dbo].[GetProcessI6InteractionsToUpdate] (
	@VCC VARCHAR(50) = NULL, 
	@ProcessId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	/*
	IF OBJECT_ID(N'tempdb..#I6_INTERACTIONS_TO_UPDATE') IS NOT NULL
	BEGIN
		DROP TABLE #I6_INTERACTIONS_TO_UPDATE
	END
	ELSE 
	BEGIN
		CREATE TABLE #I6_INTERACTIONS_TO_UPDATE(
			InteractionId VARCHAR(250)
		)
	END
	*/

	-- SELECCIONAMOS LOS ID DE INTERACIONES QUE TIENEN AUDIOS QUE REQUIEREN ACTUALIZACION DE I6
	-- INSERT INTO #I6_INTERACTIONS_TO_UPDATE
		SELECT PA.[VCC]								'vcc',
				PA.[ProcessId]						'processId',
				'CALL'								'interactionType',
				A.[ID]								'id'
			FROM [dbo].[ProcessAudio] PA (NOLOCK)
			INNER JOIN [dbo].[Audio] A (NOLOCK)
				ON A.[VCC] = PA.[VCC]
					AND A.[ID] = PA.[AudioId]
					AND A.[Section] = PA.[Section]
					AND A.[Part] = PA.[Part]
			WHERE PA.[VCC] = @VCC
				AND PA.[ProcessId] = @ProcessId
				AND A.[NeedI6Update] = 1
				AND (
					(
						ISNULL(A.[IsProcess], 0) = 0				
						AND 
						ISNULL(A.[IsTranscribed], 0) = 0
					)											-- RETORNAR SOLO LAS INTERACCIONES QUE NO HAYAN SIDO TOMADAS POR OTRO PROCESS
					OR 
					(
						A.[IsProcess] = 1						
						AND 
						A.[IsCancel] = 1
					)
				)												-- RETORNAR SOLO LAS INTERACCIONES QUE HAYAN SIDO TOMADAS Y CANCELADAS POR OTRO PROCESS
			GROUP BY PA.[VCC], PA.[ProcessId], [A].[ID]

	
	-- ACTUALIZAMOS LOS AUDIOS QUE SE VAN A TRABAJAR EN ESE PROCESS
	UPDATE A
		SET [IsProcess] = 1	-- Indicar que se esta tomando como procesando para que ningun otro procesamiento en parelelo pueda utilizar el registro.
		FROM [dbo].[ProcessAudio] PA (NOLOCK)
		INNER JOIN [dbo].[Audio] A (NOLOCK)
			ON A.[VCC] = PA.[VCC]
				AND A.[ID] = PA.[AudioId]
				AND A.[Section] = PA.[Section]
				AND A.[Part] = PA.[Part]
		WHERE PA.[VCC] = @VCC
			AND PA.[ProcessId] = @ProcessId
			AND A.[NeedI6Update] = 1
			AND (
				(
					ISNULL(A.[IsProcess], 0) = 0				
					AND 
					ISNULL(A.[IsTranscribed], 0) = 0
				)											-- RETORNAR SOLO LAS INTERACCIONES QUE NO HAYAN SIDO TOMADAS POR OTRO PROCESS
				OR 
				(
					A.[IsProcess] = 1						
					AND 
					A.[IsCancel] = 1
				)
			)												-- RETORNAR SOLO LAS INTERACCIONES QUE HAYAN SIDO TOMADAS Y CANCELADAS POR OTRO PROCESS
	
	-- SELECT * FROM [dbo].[ProcessAudio] PA (NOLOCK) WHERE [VCC] = 'incollege'
	
	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_3.6.0_database.tar.gz: database/mssql/procedures/GetProcessI6InteractionsToUpdate.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
 CREATE PROCEDURE [dbo].[GetProcessI6InteractionsToUpdate] (
	@VCC VARCHAR(50) = NULL, 
	@ProcessId VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	/*
	IF OBJECT_ID(N'tempdb..#I6_INTERACTIONS_TO_UPDATE') IS NOT NULL
	BEGIN
		DROP TABLE #I6_INTERACTIONS_TO_UPDATE
	END
	ELSE 
	BEGIN
		CREATE TABLE #I6_INTERACTIONS_TO_UPDATE(
			InteractionId VARCHAR(250)
		)
	END
	*/

	-- SELECCIONAMOS LOS ID DE INTERACIONES QUE TIENEN AUDIOS QUE REQUIEREN ACTUALIZACION DE I6
	-- INSERT INTO #I6_INTERACTIONS_TO_UPDATE
		SELECT PA.[VCC]								'vcc',
				PA.[ProcessId]						'processId',
				'CALL'								'interactionType',
				A.[ID]								'id',
				A.[NeedI6Update]					'needI6Update'
			FROM [dbo].[ProcessAudio] PA (NOLOCK)
			INNER JOIN [dbo].[Audio] A (NOLOCK)
				ON A.[VCC] = PA.[VCC]
					AND A.[ID] = PA.[AudioId]
					AND A.[Section] = PA.[Section]
					AND A.[Part] = PA.[Part]
			WHERE PA.[VCC] = @VCC
				AND PA.[ProcessId] = @ProcessId
				AND A.[NeedI6Update] = 1
				AND (
					(
						ISNULL(A.[IsProcess], 0) = 0				
						AND 
						ISNULL(A.[IsTranscribed], 0) = 0
					)											-- RETORNAR SOLO LAS INTERACCIONES QUE NO HAYAN SIDO TOMADAS POR OTRO PROCESS
					OR 
					(
						A.[IsProcess] = 1						
						AND 
						A.[IsCancel] = 1
					)
				)												-- RETORNAR SOLO LAS INTERACCIONES QUE HAYAN SIDO TOMADAS Y CANCELADAS POR OTRO PROCESS
			GROUP BY PA.[VCC], PA.[ProcessId], [A].[ID], A.[NeedI6Update]

	
	-- ACTUALIZAMOS LOS AUDIOS QUE SE VAN A TRABAJAR EN ESE PROCESS
	UPDATE A
		SET [IsProcess] = 1	-- Indicar que se esta tomando como procesando para que ningun otro procesamiento en parelelo pueda utilizar el registro.
		FROM [dbo].[ProcessAudio] PA (NOLOCK)
		INNER JOIN [dbo].[Audio] A (NOLOCK)
			ON A.[VCC] = PA.[VCC]
				AND A.[ID] = PA.[AudioId]
				AND A.[Section] = PA.[Section]
				AND A.[Part] = PA.[Part]
		WHERE PA.[VCC] = @VCC
			AND PA.[ProcessId] = @ProcessId
			AND A.[NeedI6Update] = 1
			AND (
				(
					ISNULL(A.[IsProcess], 0) = 0				
					AND 
					ISNULL(A.[IsTranscribed], 0) = 0
				)											-- RETORNAR SOLO LAS INTERACCIONES QUE NO HAYAN SIDO TOMADAS POR OTRO PROCESS
				OR 
				(
					A.[IsProcess] = 1						
					AND 
					A.[IsCancel] = 1
				)
			)												-- RETORNAR SOLO LAS INTERACCIONES QUE HAYAN SIDO TOMADAS Y CANCELADAS POR OTRO PROCESS
	
	-- SELECT * FROM [dbo].[ProcessAudio] PA (NOLOCK) WHERE [VCC] = 'incollege'
	
	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
